pub trait QuicSocketBinder { }Expand description
Noop trait for when the quinn dependency is not available.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait QuicSocketBinder { }Noop trait for when the quinn dependency is not available.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".